[tor-commits] [stem/master] Enum EXTOR and HTTPTUNNEL listener values

atagar at torproject.org atagar at torproject.org
Sat May 11 16:44:07 UTC 2019


commit 1e5e70e89dcb1d01a5bec841620d662abb39a3c6
Author: Damian Johnson <atagar at torproject.org>
Date:   Sat May 11 09:35:15 2019 -0700

    Enum EXTOR and HTTPTUNNEL listener values
    
    Adding a couple listener types we were missing...
    
      https://gitweb.torproject.org/torspec.git/tree/control-spec.txt#n924
    
    Caught thanks to Joel.
---
 stem/control.py | 29 ++++++++++++++++++-----------
 1 file changed, 18 insertions(+), 11 deletions(-)

diff --git a/stem/control.py b/stem/control.py
index 9c689ae6..a821634a 100644
--- a/stem/control.py
+++ b/stem/control.py
@@ -229,17 +229,22 @@ If you're fine with allowing your script to raise exceptions then this can be mo
 
   Purposes for inbound connections that Tor handles.
 
-  ============= ===========
-  Listener      Description
-  ============= ===========
-  **OR**        traffic we're relaying as a member of the network (torrc's **ORPort** and **ORListenAddress**)
-  **DIR**       mirroring for tor descriptor content (torrc's **DirPort** and **DirListenAddress**)
-  **SOCKS**     client traffic we're sending over Tor (torrc's **SocksPort** and **SocksListenAddress**)
-  **TRANS**     transparent proxy handling (torrc's **TransPort** and **TransListenAddress**)
-  **NATD**      forwarding for ipfw NATD connections (torrc's **NatdPort** and **NatdListenAddress**)
-  **DNS**       DNS lookups for our traffic (torrc's **DNSPort** and **DNSListenAddress**)
-  **CONTROL**   controller applications (torrc's **ControlPort** and **ControlListenAddress**)
-  ============= ===========
+  .. versionchanged:: 1.8.0
+     Added the EXTOR and HTTPTUNNEL listeners.
+
+  =============== ===========
+  Listener        Description
+  =============== ===========
+  **OR**          traffic we're relaying as a member of the network (torrc's **ORPort** and **ORListenAddress**)
+  **DIR**         mirroring for tor descriptor content (torrc's **DirPort** and **DirListenAddress**)
+  **SOCKS**       client traffic we're sending over Tor (torrc's **SocksPort** and **SocksListenAddress**)
+  **TRANS**       transparent proxy handling (torrc's **TransPort** and **TransListenAddress**)
+  **NATD**        forwarding for ipfw NATD connections (torrc's **NatdPort** and **NatdListenAddress**)
+  **DNS**         DNS lookups for our traffic (torrc's **DNSPort** and **DNSListenAddress**)
+  **CONTROL**     controller applications (torrc's **ControlPort** and **ControlListenAddress**)
+  **EXTOR**       pluggable transport for Extended ORPorts (torrc's **ExtORPort**)
+  **HTTPTUNNEL**  http tunneling proxy (torrc's **HTTPTunnelPort**)
+  =============== ===========
 """
 
 import calendar
@@ -338,6 +343,8 @@ Listener = stem.util.enum.UppercaseEnum(
   'NATD',
   'DNS',
   'CONTROL',
+  'EXTOR',
+  'HTTPTUNNEL',
 )
 
 # torrc options that cannot be changed once tor's running



More information about the tor-commits mailing list